@@ -19,6 +19,7 @@ class Expression:
     """
 
     arg_types = {"this": True}
+    __slots__ = ("key", "args", "parent", "arg_key")
 
     def __init__(self, **args):
         self.key = self.__class__.__name__.lower()
@@ -237,10 +238,6 @@ class Cache(Expression):
     }
 
 
-class Command(Expression):
-    arg_types = {"this": True, "expression": False}
-
-
 class Create(Expression):
     arg_types = {
         "this": True,
@@ -478,6 +475,13 @@ class DataType(Expression):
         MAP = auto()
 
 
+# Commands to interact with the databases or engines
+# These expressions don't truly parse the expression and consume
+# whatever exists as a string until the end or a semicolon
+class Command(Expression):
+    arg_types = {"this": True, "expression": False}
+
+
 # Binary Expressions
 # (ADD a b)
 # (FROM table selects)
